spinning_wheel_package library
Classes
- Pointer
- SpinningWheel
- A customizable Flutter widget that displays an interactive spinning wheel.
- SpinningWheelController
- A controller to programmatically trigger the spinning wheel.
- Wheel
- A custom painter for the main spinning wheel.
- WheelItem
- A data class for each section of the wheel.
- WheelShadowPainter
Enums
- PegPosition
- Defines the position of the pegs on the wheel slices.
- PointerType
- Defines the shape of the default pointer.
- WheelRimType
- Defines the visual style of the wheel's outer rim.
- WheelTextOrientation
- Defines the orientation of the text within each wheel slice.